This repo contains Python implementations of methods described in the following:

Dynamics of event‐related causality in brain electrical activity
(Korzeniewska et al. 2008) <https://doi.org/10.1002/hbm.20458>

The MVGC multivariate Granger causality toolbox: A new approach to Granger-causal inference (Barnett and Seth 2014) <https://doi.org/10.1016/j.jneumeth.2013.10.018>
